@@ -51,6 +51,8 @@ WPR2.matrix <- function(predictions, projected_model, p = 2, method = "exact", b
   
   stopifnot(p >= 1)
   
+  if(is.null(dim(predictions))) predictions <- t(as.matrix(predictions))
+  
   n <- nrow(predictions)
   d <- ncol(predictions)
   
@@ -62,7 +64,7 @@ WPR2.matrix <- function(predictions, projected_model, p = 2, method = "exact", b
     }
   }
   
-  wp_mod <- WpProj::wasserstein(predictions, projected_model, p = p, ground_p = p,
+  wp_mod <- approxOT::wasserstein(X = predictions, Y = projected_model, p = p, ground_p = p,
                                 method = method, ...)^p
   
   if(is.null(base)) {
@@ -88,12 +90,12 @@ WPR2.matrix <- function(predictions, projected_model, p = 2, method = "exact", b
   # wp_base <- if(method == "exact") {
   #   mean(colSums((predictions - mu)^p))
   # } else {
-  #   WpProj::wasserstein(predictions, mu, p = p, 
+  #   approxOT::wasserstein(predictions, mu, p = p, 
   #                      ground_p = p,
   #                      method = method, 
   #                      ...)^p
   # }
-  wp_base <- WpProj::wasserstein(predictions, mu, p = p, 
+  wp_base <- approxOT::wasserstein(X = predictions, Y = mu, p = p, 
                                  ground_p = p,
                                  method = method, 
                                  ...)^p
@@ -222,6 +224,9 @@ WPR2.WpProj <- function(predictions, projected_model, ...) {
 methods::setMethod("WPR2", signature = c("predictions" = "ANY", projected_model = "WpProj"), definition = WPR2.WpProj)
 
 plot.WPR2 <- function(x, xlim = NULL, ylim = NULL, linesize = 0.5, pointsize = 1.5, facet.group = NULL, ...) {
+  stopifnot("'ggplot2' must be installed to use this function" = rlang::is_installed("ggplot2"))
+  stopifnot("'ggsci' must be installed to use this function" = rlang::is_installed("ggsci"))
+  
   object <- x
   obj <- object
   stopifnot(inherits(obj, "WPR2"))
@@ -425,7 +430,9 @@ combine.WPR2 <- function(...) {
 #'                options = list(penalty = "lasso")
 #' )
 #' obj <- WPR2(predictions = post_mu, projected_model = fit)
+#' if (rlang::is_installed("ggplot2")) {
 #' p <- plot(obj)
+#' }
 setMethod("plot", c("x" = "WPR2"), plot.WPR2)
 
 set_y_limits_gen <- function(vals, ylim){
