@@ -48,4 +48,8 @@ register_solver <- function(solution.method) {
          lp =  ROI::ROI_require_solver("lpsolve"),
          cplex = ROI::ROI_require_solver("cplex")
   )
-}
\ No newline at end of file
+}
+
+is_inst <- function(pkg) {
+  nzchar(find.package(pkg, quiet=TRUE))
+}
